@@ -51,30 +51,30 @@ static GnomeUIInfo edit1_menu_uiinfo[] =
 {
  	{
  	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
-	 cb_renice, NULL, NULL, 0, 0,
+	 cb_renice, NULL, NULL, 0, NULL,
 	 'r', GDK_CONTROL_MASK
 	},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
-	 cb_hide_process, NULL, NULL, 0, 0,
+	 cb_hide_process, NULL, NULL, 0, NULL,
 	 'h', GDK_CONTROL_MASK
 	}, 
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("End _Process"), N_("Force a process to finish."),
-	 cb_end_process, NULL, NULL, 0, 0,
+	 cb_end_process, NULL, NULL, 0, NULL,
 	 'e', GDK_CONTROL_MASK
 	},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now."),
-	 cb_kill_process, NULL, NULL, 0, 0,
+	 cb_kill_process, NULL, NULL, 0, NULL,
 	 'k', GDK_CONTROL_MASK
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Hidden Processes"), 
 	 		    N_("View and edit your list of hidden processes"),
-	 cb_show_hidden_processes, NULL, NULL, 0, 0,
+	 cb_show_hidden_processes, NULL, NULL, 0, NULL,
 	 'p', GDK_CONTROL_MASK
 	},
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM (cb_preferences_activate, NULL),
@@ -85,18 +85,18 @@ static GnomeUIInfo view1_menu_uiinfo[] =
 {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
-	 cb_show_memory_maps, NULL, NULL, 0, 0,
+	 cb_show_memory_maps, NULL, NULL, 0, NULL,
 	 'm', GDK_CONTROL_MASK
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("Process _Dependencies"), N_("Display a tree showing process dependencies"),
-	 cb_toggle_tree, NULL, NULL, 0, 0,
+	 cb_toggle_tree, NULL, NULL, 0, NULL,
 	 'd', GDK_CONTROL_MASK
 	}, 
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Threads"), N_("Display threads (subprocesses)"),
-	 cb_toggle_threads, NULL, NULL, 0, 0,
+	 cb_toggle_threads, NULL, NULL, 0, NULL,
 	 't', GDK_CONTROL_MASK
 	}, 
 	GNOMEUIINFO_END
@@ -118,53 +118,33 @@ static GnomeUIInfo menubar1_uiinfo[] =
 	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo view_optionmenu[] = 
-{
-	{
- 	  GNOME_APP_UI_ITEM, N_("All Processes"), N_("View processes being run by all users"),
-	 cb_all_process_menu_clicked, NULL, NULL, 0, 0,
-	 't', GDK_CONTROL_MASK
-	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("My Processes"), N_("View processes being run by you"),
-	 cb_my_process_menu_clicked, NULL, NULL, 0, 0,
-	 'p', GDK_CONTROL_MASK
-	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("Active Processes"), N_("View only active processes"),
-	 cb_running_process_menu_clicked, NULL, NULL, 0, 0,
-	 'o', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_END
-};
-
 static GnomeUIInfo popup_menu_uiinfo[] =
 {
 	{
  	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
-	 popup_menu_renice, NULL, NULL, 0, 0,
+	 popup_menu_renice, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	{
  	  GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
-	 popup_menu_show_memory_maps, NULL, NULL, 0, 0,
+	 popup_menu_show_memory_maps, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
  	  GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
-	 popup_menu_hide_process, NULL, NULL, 0, 0,
+	 popup_menu_hide_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
  	  GNOME_APP_UI_ITEM, N_("_End Process"), N_("Force a process to finish"),
-	 popup_menu_end_process, NULL, NULL, 0, 0,
+	 popup_menu_end_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	{
  	  GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now"),
-	 popup_menu_kill_process, NULL, NULL, 0, 0,
+	 popup_menu_kill_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	GNOMEUIINFO_END
@@ -185,7 +165,6 @@ get_sys_pane_pos (void)
 	return GTK_PANED (sys_pane)->child1_size;
 }
 
-
 static GtkWidget *
 create_proc_view (ProcData *procdata)
 {
@@ -193,19 +172,18 @@ create_proc_view (ProcData *procdata)
 	GtkWidget *hbox1;
 	GtkWidget *search_label;
 	GtkWidget *search_entry;
-	GtkWidget *optionmenu1;
-	GtkWidget *optionmenu1_menu;
+	GtkWidget *proc_combo;
 	GtkWidget *scrolled;
 	GtkWidget *infobox;
 	GtkWidget *label;
 	GtkWidget *hbox2;
-	
+
 	vbox1 = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
 	
 	hbox1 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
-	
+
 	search_label = gtk_label_new_with_mnemonic (_("Sea_rch:"));
 	gtk_box_pack_start (GTK_BOX (hbox1), search_label, FALSE, FALSE, 0);
 	
@@ -214,29 +192,31 @@ create_proc_view (ProcData *procdata)
 	g_signal_connect (G_OBJECT (search_entry), "activate",
 			  G_CALLBACK (cb_search), procdata);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (search_label), search_entry);
-	
-	optionmenu1 = gtk_option_menu_new ();
-	gtk_box_pack_end (GTK_BOX (hbox1), optionmenu1, FALSE, FALSE, 0);
-  	optionmenu1_menu = gtk_menu_new ();
 
-  	gnome_app_fill_menu_with_data (GTK_MENU_SHELL (optionmenu1_menu), view_optionmenu,
-  			               NULL, TRUE, 0, procdata);
+	proc_combo = gtk_combo_box_new_text ();
+	gtk_box_pack_end (GTK_BOX (hbox1), proc_combo, FALSE, FALSE, 0);
+
+	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ALL_PROCESSES, _("All Processes"));
+	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), MY_PROCESSES, _("My Processes"));
+	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ACTIVE_PROCESSES, _("Active Processes"));
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (proc_combo), procdata->config.whose_process);
+
+	g_signal_connect (G_OBJECT (proc_combo), "changed",
+			  G_CALLBACK (cb_proc_combo_changed), procdata);
 
-	gtk_menu_set_active (GTK_MENU (optionmenu1_menu), procdata->config.whose_process);
-  	gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu1), optionmenu1_menu);
-  	  	
   	label = gtk_label_new_with_mnemonic (_("Vie_w:"));
-  	gtk_label_set_mnemonic_widget (GTK_LABEL (label), optionmenu1);
+  	gtk_label_set_mnemonic_widget (GTK_LABEL (label), proc_combo);
 	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-	
+
 	gtk_widget_show_all (hbox1);
-	
+
 	scrolled = proctable_new (procdata);
 	if (!scrolled)
 		return NULL;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
                                              GTK_SHADOW_IN);
-	
+
 	gtk_box_pack_start (GTK_BOX (vbox1), scrolled, TRUE, TRUE, 0);
 	
 	gtk_widget_show_all (scrolled);
@@ -266,7 +246,7 @@ create_proc_view (ProcData *procdata)
  	gnome_app_fill_menu_with_data (GTK_MENU_SHELL (popup_menu), popup_menu_uiinfo,
   			               NULL, TRUE, 0, procdata);
 	gtk_widget_show (popup_menu);
-      
+
         return vbox1;
 }
 
@@ -395,6 +375,7 @@ create_sys_view (ProcData *procdata)
 	sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	for (i=0;i<procdata->config.num_cpus; i++) {
 		GtkWidget *temp_hbox;
+		gchar *text;
 		/* Two per row */
 		if (fabs(fmod(i,2) - 0) < .01) {
 			hbox = gtk_hbox_new (FALSE, 12);
@@ -416,7 +397,7 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
 		gtk_box_pack_start (GTK_BOX (temp_hbox), color_picker, FALSE, FALSE, 0);
 		
-		gchar *text = g_strdup_printf (_("CPU%d:"), i+1);
+		text = g_strdup_printf (_("CPU%d:"), i+1);
 		label = gtk_label_new (text);
 		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 0);
 		g_free (text);
@@ -592,7 +573,7 @@ create_sys_view (ProcData *procdata)
 	gtk_tree_view_column_set_title (col, _(titles[4]));
 		
 	
-	cell = gtk_cell_renderer_progress_new ();
+	cell = procman_cell_renderer_progress_new ();
 	gtk_tree_view_column_pack_start (col, cell, TRUE);
 	gtk_tree_view_column_set_attributes (col, cell,
 					     "value", 6,
@@ -648,7 +629,7 @@ create_main_window (ProcData *procdata)
 	
 	sys_box = create_sys_view (procdata);
 	gtk_widget_show (sys_box);
-	tab_label2 = gtk_label_new_with_mnemonic (_("Resource Monitor"));
+	tab_label2 = gtk_label_new (_("Resource Monitor"));
 	gtk_widget_show (tab_label2);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label2);
 	
@@ -791,18 +772,23 @@ toggle_infoview (ProcData *data)
 	}
 }
 
-void do_popup_menu (ProcData *data, GdkEventButton *event)
+void
+do_popup_menu (ProcData *data, GdkEventButton *event)
 {
+	gint button;
+	gint event_time;
 
-	if (event->type == GDK_BUTTON_PRESS)
-        {
-                if (event->button == 3)
-                {
-                	gtk_menu_popup (GTK_MENU (popup_menu), NULL, NULL,
-                                        NULL, NULL, event->button,
-                                        event->time);
-                }
-        }
+	if (event) {
+		button = event->button;
+		event_time = event->time;
+	}
+	else {
+		button = 0;
+		event_time = gtk_get_current_event_time ();
+	}
+
+	gtk_menu_popup (GTK_MENU (popup_menu), NULL, NULL,
+			NULL, NULL, button, event_time);
 }
 
 void
